Shows which patients have which modalities at which timepoints.
Value
Tibble in wide format with one row per patient and one column per session containing the modality.
Examples
if (FALSE) { # \dontrun{
reg <- validate_registry("imaging_registry.csv", strict = FALSE)
cm <- coverage_matrix(reg)
} # }